@@ -5,7 +5,9 @@ from .tracer import (
     start_span,
     end_span,
     end_trace,
-)
+    track_function,
+    VeriskTracer
+) 
 
 __all__ = [
     "init_sqs",
@@ -15,4 +17,6 @@ __all__ = [
     "end_span",
     "end_trace",
     "get_cfg",
+    "track_function",
+    "VeriskTracer",
 ]
